﻿
-- declard color codes for console messages
local RED     = "|cffff0000"
local GREEN   = "|cff00ff00"
local BLUE    = "|cff0000ff"
local MAGENTA = "|cffff00ff"
local YELLOW  = "|cffffff00"
local CYAN    = "|cff00ffff"
local WHITE   = "|cffffffff"
local ORANGE  = "|cffffba00"

local Nauticus = Nauticus
local platforms, transports, transitData =
	Nauticus.platforms, Nauticus.transports, Nauticus.transitData
local L = Naut_localise

-- local variables
local varsLoaded = false
local dropdownvalues = {}
local dropdownindex = {}

function Nauticus:TransportSelectInitialise()
	local info
	dropdownvalues = {}

	for i = 0, #(transports), 1 do
		dropdownindex[transports[i].label] = i

		local textdesc

		if nautSavedVars.config.CityAlias then
			if self:GetKnownData(transports[i].label) then
				textdesc = GREEN..transports[i].namealias
			else
				textdesc = transports[i].namealias
			end
		else
			if self:GetKnownData(transports[i].label) then
				textdesc = GREEN..transports[i].name
			else
				textdesc = transports[i].name
			end
		end

		info = {
			text = textdesc;
			func = function() Nauticus:TransportSelect_OnClick() end;
		}

		local addtrans = false

		if nautSavedVars.config.FactionSpecific then
			local faction = UnitFactionGroup("player")

			if transports[i].faction == faction or
				transports[i].faction == "Neutral" then

				addtrans = true
			end
		else
			addtrans = true
		end

		if addtrans and nautSavedVars.config.ZoneSpecific then
			local zonestr = string.lower(transports[i].name)
			local czonestr = string.lower(GetRealZoneText())

			if not string.find(zonestr, czonestr) then
				addtrans = false
			end
		end

		if addtrans or transports[i].faction == -1 then
			UIDropDownMenu_AddButton(info)
			table.insert(dropdownvalues, transports[i].label)
		end
	end

end

function Nauticus:TransportSelectPreInitialise()
	local info = {
		text = 'loading variables';
		func = function() self:TransportSelect_OnClick() end;
	}

	UIDropDownMenu_AddButton(info)
end

function Nauticus:TransportSelect_OnShow()
	if varsLoaded then
		self:TransportSelect_OnLoaded()
		UIDropDownMenu_SetWidth(162)
		return
	end

	UIDropDownMenu_ClearAll(NautFrameTransportSelect)
	UIDropDownMenu_Initialize(NautFrameTransportSelect, function() Nauticus:TransportSelectPreInitialise() end )
	UIDropDownMenu_SetSelectedID(NautFrameTransportSelect, 1)
	UIDropDownMenu_SetWidth(162)
end

function Nauticus:TransportSelect_OnLoaded()
	UIDropDownMenu_ClearAll(NautFrameTransportSelect)
	UIDropDownMenu_Initialize(NautFrameTransportSelect, function() Nauticus:TransportSelectInitialise() end )
	UIDropDownMenu_SetSelectedID(NautFrameTransportSelect, self.activeSelect)
end

function Nauticus:TransportSelect_OnClick()
	local i = this:GetID()

	UIDropDownMenu_SetSelectedID(NautFrameTransportSelect, i)
	Nauticus.activeTransit = dropdownvalues[i]
	nautSavedVarsPC.config.activeTransit = Nauticus.activeTransit
	Nauticus.activeSelect = i

	if nautSavedVars.config.CityAlias then
		Nauticus.activeTransitName = transports[dropdownindex[Nauticus.activeTransit] ].namealias
	else
		Nauticus.activeTransitName = transports[dropdownindex[Nauticus.activeTransit] ].name
	end

	Nauticus:TransportSelectSetNone()
end

function Nauticus:TransportSelectSetNone()

	if self.activeTransit == -1 then
		if self.debug then
			self:DebugMessage("_OnClick - no transit")
		end

		for index = 1, 2 do
			getglobal("NautFramePlat"..(index).."Name"):SetText(L["NONESELECT"])
			getglobal("NautFramePlat"..(index).."ArrivalDepature"):SetText("-- N/A --")
		end

		self.lowestNameTime = "--"
		self.icon = "NauticusLogo"

	elseif self:GetKnownData(self.activeTransit) == nil then
		local transit = self.activeTransit

		if self.debug then
			self:DebugMessage("_OnClick - unknown transit: "..transit)
		end

		for index, data in pairs(platforms[transit]) do
			local platname

			if nautSavedVars.config.CityAlias then
				platname = data.alias
			else
				platname = data.name
			end

			getglobal("NautFramePlat"..(index+1).."Name"):SetText(platname)
			getglobal("NautFramePlat"..(index+1).."ArrivalDepature"):SetText("-- N/A --")
		end

		self.lowestNameTime = "N/A"
		self.icon = "NauticusLogo"

	else
		lastIndex = 1

	end

end

function Nauticus:Minimise_OnClick()
	nautSavedVarsPC.config.ShowLowerGUI = not nautSavedVarsPC.config.ShowLowerGUI
	self:UpdateUI()
end

function Nauticus:UpdateUI()

	if nautSavedVarsPC.config.ShowLowerGUI then
		NautHeaderFrame:SetWidth(210)
		NautHeaderFrameAddonName:Show()
		NautHeaderFrameOptionsButton:Show()
		NautFrame:Show()
		NautHeaderFrameMinimiseButton:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-UP")
		NautHeaderFrameMinimiseButton:SetPushedTexture("Interface\\Buttons\\UI-MinusButton-DOWN")

		local _, centre = NautHeaderFrame:GetCenter()
		NautFrame:ClearAllPoints()

		if centre < (GetScreenHeight()/2) then
			NautFrame:SetPoint("BOTTOM", NautHeaderFrame, "TOP", 0, -5)
		else
			NautFrame:SetPoint("TOP", NautHeaderFrame, "BOTTOM", 0, 5)
		end

	else
		NautFrame:Hide()
		NautHeaderFrameMinimiseButton:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-UP")
		NautHeaderFrameMinimiseButton:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-DOWN")
		NautHeaderFrameOptionsButton:Hide()
		NautHeaderFrameAddonName:Hide()

		-- initialise anchor
		local right = NautHeaderFrame:GetRight()
		local top = NautHeaderFrame:GetTop()

		if top ~= nil and right ~= nil then
			NautHeaderFrame:ClearAllPoints()
			NautHeaderFrame:SetPoint("TOPRIGHT", UIParent, "BOTTOMLEFT", right, top)
		end

		NautHeaderFrame:SetWidth(64)
	end

end

function Nauticus:Close_OnClick()
	NautHeaderFrame:Hide()
	nautSavedVarsPC.config.ShowGUI = false

	DEFAULT_CHAT_FRAME:AddMessage(YELLOW.. "Nauticus|r - "..WHITE..
		"GUI closed. Type /nauticus or /naut to show again.")
end

function Nauticus:Options_OnClick()

	if not NautOptionsFrame:IsVisible() then
		NautOptionsFrame:Show()
	else
		NautOptionsFrame:Hide()
	end

end

function Nauticus:OptionsSave_OnClick()

	nautSavedVars.config.ZoneGUI = NautOptionsFrameOptZoneGUI:GetChecked()
	nautSavedVars.config.FactionSpecific = NautOptionsFrameOptFactionSpecific:GetChecked()
	nautSavedVars.config.ZoneSpecific = NautOptionsFrameOptZoneSpecific:GetChecked()
	nautSavedVars.config.CityAlias = NautOptionsFrameOptCityAlias:GetChecked()

	-- refresh dropdown with current options applied
	self:TransportSelect_OnLoaded()
	NautOptionsFrame:Hide()

end

function Nauticus:OptionsClose_OnClick()

	if nautSavedVars.config.ZoneGUI then
		NautOptionsFrameOptZoneGUI:SetChecked()
	end
	if nautSavedVars.config.FactionSpecific then
		NautOptionsFrameOptFactionSpecific:SetChecked()
	end
	if nautSavedVars.config.ZoneSpecific then
		NautOptionsFrameOptZoneSpecific:SetChecked()
	end
	if nautSavedVars.config.CityAlias then
		NautOptionsFrameOptCityAlias:SetChecked()
	end

	NautOptionsFrame:Hide()

end

function Nauticus:InitialiseUI()

	local cfg = nautSavedVars.config
	local cfgPC = nautSavedVarsPC.config

	-- set GUI options
	if cfg.ZoneGUI then
		NautOptionsFrameOptZoneGUI:SetChecked()
	end
	if cfg.FactionSpecific then
		NautOptionsFrameOptFactionSpecific:SetChecked()
	end
	if cfg.ZoneSpecific then
		NautOptionsFrameOptZoneSpecific:SetChecked()
	end
	if cfg.CityAlias then
		NautOptionsFrameOptCityAlias:SetChecked()
	end

	self:TransportSelect_OnLoaded()

	if cfg.CityAlias then
		self.activeTransitName = transports[dropdownindex[self.activeTransit] ].namealias
	else
		self.activeTransitName = transports[dropdownindex[self.activeTransit] ].name
	end

	varsLoaded = true

	if cfgPC.ShowLowerGUI then
		NautFrame:Show()
	else
		NautFrame:Hide()
	end

	if cfgPC.ShowGUI then
		NautHeaderFrame:Show()
	else
		NautHeaderFrame:Hide()
	end

	NautHeaderFrameAddonName:SetText("Nauticus v"..self.nautVersion);
	NautOptionsFrameOptionsTitle:SetText("Nauticus Options (v"..self.nautVersion..")")
	DEFAULT_CHAT_FRAME:AddMessage(YELLOW.. "Nauticus v"..self.nautVersion.." loaded. Type /nauticus or /naut to show GUI.")

end
