﻿
-- declard color codes for console messages
local RED     = "|cffff0000"
local GREEN   = "|cff00ff00"
local BLUE    = "|cff0000ff"
local MAGENTA = "|cffff00ff"
local YELLOW  = "|cffffff00"
local CYAN    = "|cff00ffff"
local WHITE   = "|cffffffff"
local ORANGE  = "|cffffba00"

local Nauticus = Nauticus
local platforms, transports, transitData =
	Nauticus.platforms, Nauticus.transports, Nauticus.transitData
local L = Naut_localise

-- constants
local TITAN_NAUT_ID = "Nauticus"
local TITAN_NAUT_MENU_TEXT = "Nauticus"
local TITAN_NAUT_VERSION = "2.1.2"
local TITAN_NAUT_TOOLTIP = "Nauticus"
local TITAN_NAUT_FREQUENCY = 1
local TITAN_NAUT_ARTWORK = "Interface\\AddOns\\Nauticus\\Artwork\\"

-- local variables
local dropdownvalues = {}
local dropdownindexes = {}

function TitanPanelNauticusButton_OnLoad()

	-- make sure Nauticus loads first
	LoadAddOn("Nauticus")

	this.registry = {
		id = TITAN_NAUT_ID,
		category = "Information",
		version = TITAN_NAUT_VERSION,
		menuText = TITAN_NAUT_MENU_TEXT, 
		buttonTextFunction = "TitanPanelNauticusButton_GetButtonText",
		tooltipTitle = TITAN_NAUT_TOOLTIP,
		tooltipTextFunction = "TitanPanelNauticusButton_GetTooltipText",
		frequency = TITAN_NAUT_FREQUENCY,
		icon = TITAN_NAUT_ARTWORK.."NauticusLogo",
		iconWidth = 16,
		savedVariables = {
			--OptZoneGUI = 1,
			OptFaction = 1,
			OptZone = false,
			OptAlias = 1,
			ShowLabelText = 1,
			ShowIcon = 1,
		}
	}

	this:RegisterEvent("ZONE_CHANGED_NEW_AREA")

	Pre_TitanToggleVar = TitanToggleVar
	TitanToggleVar = Naut_TitanToggleVar

end

-- hook toggle button
function Naut_TitanToggleVar(id, var)
	if id == TITAN_NAUT_ID then
		TitanPanelRightClickMenu_Close()
	end

	return Pre_TitanToggleVar(id, var)
end

function TitanPanelNauticusButton_OnEvent()

	if event == "ZONE_CHANGED_NEW_AREA" then
		TitanPanelRightClickMenu_Close()
	end

end

function TitanPanelNauticusButton_GetButtonText(id)

	if Nauticus:IsAlarmSet() then
		TitanPanelNauticusButton.registry.icon = "Interface\\Icons\\INV_Misc_PocketWatch_02"
	else
		TitanPanelNauticusButton.registry.icon = TITAN_NAUT_ARTWORK..Nauticus.icon
	end

	if Nauticus.tempTextCount > 0 then
		Nauticus.tempTextCount = Nauticus.tempTextCount -1
		return Nauticus.tempText
	end

	return Nauticus.lowestNameTime

end

function TitanPanelNauticusButton_GetTooltipText()

	local OptAlias = TitanGetVar(TITAN_NAUT_ID, "OptAlias")
	local toolTipText = ""

	if Nauticus.activeTransit ~= -1 and Nauticus:GetKnownData(Nauticus.activeTransit) ~= nil then
		local transit = Nauticus.activeTransit

		toolTipText = toolTipText..Nauticus.activeTransitName.."\n\n"

		for index, data in pairs(platforms[transit]) do
			local platname

			if OptAlias then
				platname = data.alias
			else
				platname = data.name
			end

			toolTipText = toolTipText..WHITE..platname.."\n"

			local the_time = Nauticus.activeData[index]

			if the_time <= 0 then
				the_time = -the_time

				local color

				if the_time > 30 then
					color = YELLOW
				else
					color = RED
				end

				toolTipText = toolTipText.."Departure:\t"..color
			else
				toolTipText = toolTipText.."Arrival:\t"..GREEN
			end

			if the_time >= 60 then
				toolTipText = toolTipText..format("%dm %02ds\n\n", the_time/60,
					math.fmod(the_time, 60) )
			else
				toolTipText = toolTipText..format("%ds\n\n", the_time)
			end

		end

	elseif Nauticus.activeTransit ~= -1 and Nauticus:GetKnownData(Nauticus.activeTransit) == nil then
		local transit = Nauticus.activeTransit

		toolTipText = toolTipText..Nauticus.activeTransitName.."\n\n"

		for index, data in pairs(platforms[transit]) do
			local platname

			if OptAlias then
				platname = data.alias
			else
				platname = data.name
			end

			toolTipText = toolTipText..WHITE..platname.."\nNot Available\n\n"
		end

	elseif Nauticus.activeTransit == -1 then
		toolTipText = toolTipText.."No Transit Selected\n"

	end

	toolTipText = toolTipText..GREEN.."Hint: "..L["HINT"]

	return toolTipText
end

function TitanPanelRightClickMenu_PrepareNauticusMenu()

	local OptFaction = TitanGetVar(TITAN_NAUT_ID, "OptFaction")
	local OptZone = TitanGetVar(TITAN_NAUT_ID, "OptZone")
	local OptAlias = TitanGetVar(TITAN_NAUT_ID, "OptAlias")

	dropdownvalues = {}
	dropdownindexes = {}

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_NAUT_ID].menuText)

	TitanPanelRightClickMenu_AddToggleVar(L["OPT_FACTION"], TITAN_NAUT_ID, "OptFaction")
	TitanPanelRightClickMenu_AddToggleVar(L["OPT_ZONE"], TITAN_NAUT_ID, "OptZone")
	TitanPanelRightClickMenu_AddToggleVar(L["OPT_ALIAS"], TITAN_NAUT_ID, "OptAlias")

	TitanPanelRightClickMenu_AddSpacer()
	TitanPanelRightClickMenu_AddCommand(YELLOW.."Select None", -1, "TitanPanelNauticusButton_SetTransport")

	local count = 1

	for index, data in pairs(transports) do
		--local tmplabel = data.label
		local textdesc

		dropdownindexes[data.label] = index

		if OptAlias then
			textdesc = transports[index].namealias
		else
			textdesc = transports[index].name
		end

		local addtrans = false

		if OptFaction then
			local faction = UnitFactionGroup("player")

			if transports[index].faction == faction or transports[index].faction == "Neutral" then
				addtrans = true
			end

		else
			addtrans = true

		end

		if addtrans and OptZone then
			local zonestr = string.lower(transports[index].name)
			local czonestr = string.lower( GetRealZoneText() )

			if not string.find(zonestr, czonestr) then
				addtrans = false
			end
		end

		if addtrans and transports[index].faction ~= -1 then
			table.insert(dropdownvalues, transports[index].label)
			label = transports[index].label

			if Nauticus:GetKnownData(label) ~= nil then
				TitanPanelRightClickMenu_AddCommand(GREEN.. textdesc, count, "TitanPanelNauticusButton_SetTransport")
			else
				TitanPanelRightClickMenu_AddCommand(textdesc, count, "TitanPanelNauticusButton_SetTransport")
			end

			count = count + 1
		end
	end

	TitanPanelRightClickMenu_AddSpacer()
	TitanPanelRightClickMenu_AddCommand(TITAN_PANEL_MENU_HIDE, TITAN_NAUT_ID, TITAN_PANEL_MENU_FUNC_HIDE)
end

function TitanPanelNauticusButton_OnClick( event )

	if event == "LeftButton" then

		if IsAltKeyDown() then
			if Nauticus.activeTransit ~= -1 then
				Nauticus:ToggleAlarm()
			
				-- set temporary button text so you know which one is currently selected
				if Nauticus:IsAlarmSet() then
					Nauticus.tempText = "Alarm "..RED.."ON"
				else
					Nauticus.tempText = "Alarm OFF"
				end
			
				Nauticus.tempTextCount = 2
				TitanPanelButton_SetButtonText(TITAN_NAUT_ID)
				--Nauticus.updateNow = true;
			end

			return
		end

		if #(dropdownvalues) == 0 then
			Nauticus.activeSelect = -1
			Nauticus.activeTransit = -1
			nautSavedVarsPC.config.activeTransit = -1
			return

		elseif Nauticus.activeSelect == -1 then
			Nauticus.activeSelect = 1

		else
			Nauticus.activeSelect = Nauticus.activeSelect + 1

		end

		if Nauticus.activeSelect > #(dropdownvalues) then
			Nauticus.activeSelect = 1
			Nauticus.activeTransit = dropdownvalues[Nauticus.activeSelect]
		else
			Nauticus.activeTransit = dropdownvalues[Nauticus.activeSelect]
		end

		nautSavedVarsPC.config.activeTransit = Nauticus.activeTransit

		if TitanGetVar(TITAN_NAUT_ID, "OptAlias") then
			Nauticus.activeTransitName = transports[dropdownindexes[Nauticus.activeTransit] ].namealias
		else
			Nauticus.activeTransitName = transports[dropdownindexes[Nauticus.activeTransit] ].name
		end

		local color

		if Nauticus:GetKnownData(Nauticus.activeTransit) ~= nil then
			color = GREEN
		else
			color = RED
		end

		-- set temporary button text so you know which one is currently selected
		Nauticus.tempText = color..Nauticus.activeTransitName
		Nauticus.tempTextCount = 2
		TitanPanelButton_SetButtonText(TITAN_NAUT_ID)
		Nauticus:TransportSelectSetNone()
	end
end

function TitanPanelNauticusButton_SetTransport()

	if this.value == -1 then
		Nauticus.activeSelect = -1
		Nauticus.activeTransit = -1
		nautSavedVarsPC.config.activeTransit = -1
		Nauticus.activeTransitName = L["NONESELECT"]

	else
		Nauticus.activeSelect = this.value
		Nauticus.activeTransit = dropdownvalues[this.value]
		nautSavedVarsPC.config.activeTransit = Nauticus.activeTransit

		if TitanGetVar(TITAN_NAUT_ID, "OptAlias") then
			Nauticus.activeTransitName = transports[dropdownindexes[Nauticus.activeTransit] ].namealias
		else
			Nauticus.activeTransitName = transports[dropdownindexes[Nauticus.activeTransit] ].name
		end

		Nauticus.tempText = Nauticus.activeTransitName
		Nauticus.tempTextCount = 2
	end

	Nauticus:TransportSelectSetNone()

end
